@@ -60,9 +60,9 @@ test_that('formula method', {
 
   rf_m_pred <-
     rf_m_pred %>%
-    mutate(.rows = 1:nrow(rf_m_pred)) %>%
+    mutate(.row_number = 1:nrow(rf_m_pred)) %>%
     tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .rows)
+    arrange(penalty, .row_number)
 
   for (i in vals) {
     exp_pred <- predict(rf_fit_exp, ad_pred, lambda = i)[,1]
@@ -74,9 +74,9 @@ test_that('formula method', {
 
   rf_m_prob <-
     rf_m_prob %>%
-    mutate(.rows = 1:nrow(rf_m_prob)) %>%
+    mutate(.row_number = 1:nrow(rf_m_prob)) %>%
     tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .rows)
+    arrange(penalty, .row_number)
 
   for (i in vals) {
     exp_pred <- predict(rf_fit_exp, ad_pred, lambda = i, type = "response")[,1]
@@ -139,9 +139,9 @@ test_that('non-formula method', {
 
   rf_m_pred <-
     rf_m_pred %>%
-    mutate(.rows = 1:nrow(rf_m_pred)) %>%
+    mutate(.row_number = 1:nrow(rf_m_pred)) %>%
     tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .rows)
+    arrange(penalty, .row_number)
 
   for (i in vals) {
     exp_pred <- predict(rf_fit_exp, ad_pred, lambda = i)[,1]
@@ -153,9 +153,9 @@ test_that('non-formula method', {
 
   rf_m_prob <-
     rf_m_prob %>%
-    mutate(.rows = 1:nrow(rf_m_prob)) %>%
+    mutate(.row_number = 1:nrow(rf_m_prob)) %>%
     tidyr::unnest(cols = c(.pred)) %>%
-    arrange(penalty, .rows)
+    arrange(penalty, .row_number)
 
   for (i in vals) {
     exp_pred <- predict(rf_fit_exp, ad_pred, lambda = i, type = "response")[,1]
